State

Struct State 

pub struct State {
    pub entities: Map<Name, Entity>,
    pub concepts: Map<Name, Concept>,
    pub concepts_gtin: Map<Gtin, Concept>,
    pub objects: Map<Name, Object>,
    pub balances: Map<Pair, Value>,
}
An index of directly accessible actors.

On being complete

Note that over time, actors might be come inaccessible as their names (or GTIN, in case of a concept) can be shadowed. In this case, they will never become accessible again. However, they will still be referred to when referenced elsewhere.

For example, take this script:

create concept C price 1€
create object O
create concept C price 2€

After this script was ran, object O still the former concept C with price 1€ as parent. However, only the latter concept C with price 2€ can be referred to by its name.

Fields

entities: Map<Name, Entity>concepts: Map<Name, Concept>concepts_gtin: Map<Gtin, Concept>objects: Map<Name, Object>balances: Map<Pair, Value>